/* BdfServer - Copyright (c) 2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.exportation.balayage;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.balayage.Balayage;
import java.io.StringReader;
import java.util.AbstractList;
import java.util.List;
import java.util.RandomAccess;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import net.fichotheque.extraction.def.ExtractionDef;
import net.fichotheque.tools.extraction.dom.ExtractionDOMReader;
import net.mapeadores.util.xml.DOMUtils;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;


/**
 *
 * @author Vincent Calame
 */
public final class BdfBalayageUtils {

    private BdfBalayageUtils() {

    }

    public static ExtractionDef getExtractionDef(BdfServer bdfServer, Balayage balayage, String extractionPath) throws SAXException {
        String content = bdfServer.getBalayageManager().getBalayageContent(balayage.getName(), "extraction/" + extractionPath);
        if (content == null) {
            return null;
        }
        Document document = DOMUtils.parseDocument(content);
        ExtractionDOMReader extractionDomReader = new ExtractionDOMReader(bdfServer.getFichotheque());
        ExtractionDef extractionDef = extractionDomReader.readExtraction(document.getDocumentElement(), balayage.getIncludeCatalog());
        return extractionDef;
    }

    public static Source getTransformerSource(BdfServer bdfServer, Balayage balayage, String xsltPath) {
        String content = bdfServer.getBalayageManager().getBalayageContent(balayage.getName(), "xslt/" + xsltPath);
        if (content == null) {
            return null;
        }
        return new StreamSource(new StringReader(content), "bdf://this/balayage/" + balayage.getName() + "/xslt/" + xsltPath);
    }

    public static List<Balayage> wrap(Balayage[] array) {
        return new BalayageList(array);
    }


    private static class BalayageList extends AbstractList<Balayage> implements RandomAccess {

        private final Balayage[] array;

        private BalayageList(Balayage[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public Balayage get(int index) {
            return array[index];
        }

    }

}
