/* FichothequeLib_Tools - Copyright (c) 2016-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.exportation.table.dom;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Consumer;
import net.fichotheque.tools.exportation.table.TableExportDefBuilder;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.LangsUtils;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class TableExportDefDOMReader {

    private final TableExportDefBuilder tableExportDefBuilder;
    private final MessageHandler messageHandler;

    public TableExportDefDOMReader(TableExportDefBuilder tableExportDefBuilder, MessageHandler messageHandler) {
        this.tableExportDefBuilder = tableExportDefBuilder;
        this.messageHandler = messageHandler;
    }

    public void readTableExportDef(Element element) {
        DOMUtils.readChildren(element, new RootConsumer());
    }


    private class RootConsumer implements Consumer<Element> {

        private RootConsumer() {
        }

        @Override
        public void accept(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("label")) {
                try {
                    LabelUtils.readLabel(element, tableExportDefBuilder);
                } catch (ParseException ile) {
                    DomMessages.wrongLangAttribute(messageHandler, tagName, element.getAttribute("xml:lang"));
                }
            } else if (tagName.equals("langs")) {
                String langMode = element.getAttribute("mode");
                if (langMode.length() > 0) {
                    tableExportDefBuilder.setLangMode(langMode);
                }
                List<Lang> resultList = new ArrayList<Lang>();
                LangsUtils.readLangElements(resultList, element, messageHandler, tagName);
                for (Lang lang : resultList) {
                    tableExportDefBuilder.addLang(lang);
                }
            } else if (tagName.equals("attr")) {
                AttributeUtils.readAttrElement(tableExportDefBuilder.getAttributesBuilder(), element);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
