/* FichothequeLib_Xml - Copyright (c) 2015-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.importation.dom;

import java.text.ParseException;
import java.util.function.Consumer;
import net.mapeadores.util.attr.AttributeChangeBuilder;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.CleanedString;
import net.mapeadores.util.text.LabelChangeBuilder;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.XMLUtils;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public final class ImportationDomUtils {

    private ImportationDomUtils() {

    }

    public static void readLabelElement(Element element, LabelChangeBuilder changeLabelHolderBuilder) {
        try {
            Lang lang = Lang.parse(element.getAttribute("xml:lang"));
            CleanedString libString = DOMUtils.contentToCleanedString(element);
            if (libString == null) {
                changeLabelHolderBuilder.putRemovedLang(lang);
            } else {
                changeLabelHolderBuilder.putLabel(lang, libString);
            }
        } catch (ParseException pe) {
        }
    }

    public static void readAttrElement(Element element, AttributeChangeBuilder attributeChangeBuilder) {
        AttributeKey attributeKey = AttributeUtils.readAttributeKey(element);
        if (attributeKey == null) {
            return;
        }
        AttributeConsumer attributeConsumer = new AttributeConsumer(attributeKey, attributeChangeBuilder);
        DOMUtils.readChildren(element, attributeConsumer);
        if (!attributeConsumer.isDone()) {
            attributeChangeBuilder.putRemovedAttributeKey(attributeKey);
        }
    }


    private static class AttributeConsumer implements Consumer<Element> {

        private final AttributeKey attributeKey;
        private final AttributeChangeBuilder attributeChangeBuilder;
        private boolean done = false;

        private AttributeConsumer(AttributeKey attributeKey, AttributeChangeBuilder attributeChangeBuilder) {
            this.attributeKey = attributeKey;
            this.attributeChangeBuilder = attributeChangeBuilder;
        }

        private boolean isDone() {
            return done;
        }

        @Override
        public void accept(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("val")) {
                CleanedString cs = XMLUtils.toCleanedString(element);
                if (cs != null) {
                    attributeChangeBuilder.appendValue(attributeKey, cs);
                    done = true;
                }
            }
        }

    }


}
